@@ -8,13 +8,9 @@ This is a generic library for building event-based / asynchronous
 SSL/TLS servers and clients.
 """
 
-import errno
-import os
 import socket
 import ssl as sys_ssl
-from typing import Union
 
-from thor.dns import lookup
 from thor.loop import LoopBase
 from thor.tcp import TcpClient, TcpConnection
 
@@ -42,7 +38,7 @@ class TlsClient(TcpClient):
     > c = TlsClient()
     > c.on('connect', conn_handler)
     > c.on('connect_error', error_handler)
-    > c.connect(host, port)
+    > c.connect(address)
 
     conn_handler will be called with the tcp_conn as the argument
     when the connection is made.
@@ -56,11 +52,15 @@ class TlsClient(TcpClient):
         tls_context = sys_ssl.create_default_context()
         tls_context.check_hostname = False
         tls_context.verify_mode = sys_ssl.CERT_NONE
-        self.tls_sock = tls_context.wrap_socket(  # type: ignore
-            self.sock,
-            do_handshake_on_connect=False,
-            server_hostname=self.host.decode("idna"),
-        )
+        try:
+            self.tls_sock = tls_context.wrap_socket(  # type: ignore
+                self.sock,
+                do_handshake_on_connect=False,
+                server_hostname=self.hostname.decode("idna"),
+            )
+        except OSError as why:
+            self.handle_socket_error(why, "ssl")
+            return
         self.once("fd_writable", self.handshake)
 
     def handshake(self) -> None:
@@ -84,25 +84,5 @@ class TlsClient(TcpClient):
         self.unregister_fd()
         if self._timeout_ev:
             self._timeout_ev.delete()
-        tls_conn = TcpConnection(self.tls_sock, self.host, self.port, self._loop)
+        tls_conn = TcpConnection(self.tls_sock, self.address, self._loop)
         self.emit("connect", tls_conn)
-
-
-if __name__ == "__main__":
-    import sys
-    from thor import run
-
-    test_host = sys.argv[1].encode("utf-8")
-
-    def out(outbytes: bytes) -> None:
-        sys.stdout.write(outbytes.decode("utf-8", "replace"))
-
-    def go(conn: TcpConnection) -> None:
-        conn.on("data", out)
-        conn.write(b"GET / HTTP/1.1\r\nHost: %s\r\n\r\n" % test_host)
-        conn.pause(False)
-
-    c = TlsClient()
-    c.on("connect", go)
-    c.connect(test_host, 443)
-    run()
